==> haskell-incremental-parser-0.5.1-11-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 incremental-parser
version:              0.5.1
visibility:           public
id:                   incremental-parser-0.5.1-HLPR8ORmcgZc9uNe7akvC
key:                  incremental-parser-0.5.1-HLPR8ORmcgZc9uNe7akvC
license:              GPL-3.0-only
copyright:            (c) 2011-2023 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://github.com/blamario/incremental-parser
synopsis:
    Generic parser library capable of providing partial results from partial input.

description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.

category:             Parsing
abi:                  686c9663befe9541fc8134ddc69cb2c2
exposed:              True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric

import-dirs:          /usr/lib/ghc-9.2.8/site-local/incremental-parser-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/incremental-parser-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-incremental-parser
hs-libraries:         HSincremental-parser-0.5.1-HLPR8ORmcgZc9uNe7akvC
depends:
    base-4.16.4.0 input-parsers-0.3.0.2-JkoR9xjlSImJYzE18ooHLr
    logict-0.7.1.0-2FqoCJvkdNzLCCh5fiGBZM
    monoid-subclasses-1.2.4.1-BqqIYoS5rSrGTztp4nySY
    parsers-0.12.11-BNeFON4lnWjK9sQVv7NnxL
    rank2classes-1.5.3-9gdsXAqQDC6DXVpVOPDhQx transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock

haddock-html:         /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-incremental-parser-0.5.1-24-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 incremental-parser
version:              0.5.1
visibility:           public
id:                   incremental-parser-0.5.1-EWmmNonsdX0CytXw2OeMfK
key:                  incremental-parser-0.5.1-EWmmNonsdX0CytXw2OeMfK
license:              GPL-3.0-only
copyright:            (c) 2011-2023 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://github.com/blamario/incremental-parser
synopsis:
    Generic parser library capable of providing partial results from partial input.

description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.

category:             Parsing
abi:                  eb4b04169292f2a3d93480cb72524341
exposed:              True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric

import-dirs:          /usr/lib/ghc-9.2.8/site-local/incremental-parser-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/incremental-parser-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-incremental-parser
hs-libraries:         HSincremental-parser-0.5.1-EWmmNonsdX0CytXw2OeMfK
depends:
    base-4.16.4.0 input-parsers-0.3.0.2-GIS8dc9UtBt14shBwPSeHe
    logict-0.7.1.0-4RUNWynDO5NBZa0A2p1eBM
    monoid-subclasses-1.2.5.1-sZtPOJaZ0S6evtjY5CeiJ
    parsers-0.12.11-GQJpRLe968oESf6mSDWSbn
    rank2classes-1.5.3.1-35Bz0E4bo2pHYaOTDBn3kP transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock

haddock-html:         /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
